@@ -15,6 +15,7 @@ from glob import glob
 from setuptools import Command, _dont_write_bytecode
 from setuptools.sandbox import run_setup
 from distutils import log, dir_util
+from distutils.util import get_platform
 from distutils.util import convert_path, subst_vars
 from distutils.sysconfig import get_python_lib, get_config_vars
 from distutils.errors import DistutilsArgError, DistutilsOptionError, \
@@ -202,6 +203,8 @@ class easy_install(Command):
                             'prefix': prefix,
                             'sys_exec_prefix': exec_prefix,
                             'exec_prefix': exec_prefix,
+                            # Only python 3.2+ has abiflags
+                            'abiflags': getattr(sys, 'abiflags', ''),
                            }
 
         if HAS_USER_SITE:
@@ -377,7 +380,7 @@ class easy_install(Command):
 
     def check_site_dir(self):
         """Verify that self.install_dir is .pth-capable dir, if needed"""
-        print 'install_dir', self.install_dir
+
         instdir = normalize_path(self.install_dir)
         pth_file = os.path.join(instdir,'easy-install.pth')
 
@@ -565,7 +568,8 @@ Please make the appropriate changes for your system and try again.
 
             self.check_editable(spec)
             dist = self.package_index.fetch_distribution(
-                spec, tmpdir, self.upgrade, self.editable, not self.always_copy
+                spec, tmpdir, self.upgrade, self.editable, not self.always_copy,
+                self.local_index
             )
 
             if dist is None:
@@ -638,7 +642,8 @@ Please make the appropriate changes for your system and try again.
         self.update_pth(dist)
         self.package_index.add(dist)
         self.local_index.add(dist)
-        self.install_egg_scripts(dist)
+        if not self.editable:
+            self.install_egg_scripts(dist)
         self.installed_projects[dist.key] = dist
         log.info(self.installation_report(requirement, dist, *info))
         if (dist.has_metadata('dependency_links.txt') and
@@ -850,7 +855,7 @@ Please make the appropriate changes for your system and try again.
         # Create a dummy distribution object until we build the real distro
         dist = Distribution(None,
             project_name=cfg.get('metadata','name'),
-            version=cfg.get('metadata','version'), platform="win32"
+            version=cfg.get('metadata','version'), platform=get_platform()
         )
 
         # Convert the .exe to an unpacked egg
@@ -1443,7 +1448,8 @@ def get_exe_prefixes(exe_filename):
     prefixes = [
         ('PURELIB/', ''), ('PLATLIB/pywin32_system32', ''),
         ('PLATLIB/', ''),
-        ('SCRIPTS/', 'EGG-INFO/scripts/')
+        ('SCRIPTS/', 'EGG-INFO/scripts/'),
+        ('DATA/LIB/site-packages', ''),
     ]
     z = zipfile.ZipFile(exe_filename)
     try:
